Image
=====

The ``Image`` class, which lets you specify a pre-built base Image to use
at launch time, as well as additional setup steps required for your program, such as installs and env vars.

Image Class
~~~~~~~~~~~

.. autoclass:: kubetorch.Image
   :members:
   :undoc-members:

    .. automethod:: __init__
